==> zio-aws-rds_2.12-5.17.129.1-sources.jar: zio/aws/rds/model/DescribeDbSubnetGroupsResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeDbSubnetGroupsResponse(
    marker: scala.Option[String] = None,
    dbSubnetGroups: scala.Option[Iterable[zio.aws.rds.model.DBSubnetGroup]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse = {
    import DescribeDbSubnetGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbSubnetGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbSubnetGroups)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbSubnetGroupsResponse.wrap(buildAwsValue())
}
object DescribeDbSubnetGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbSubnetGroupsResponse =
      zio.aws.rds.model.DescribeDbSubnetGroupsResponse(
        marker.map(value => value),
        dbSubnetGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: scala.Option[String]
    def dbSubnetGroups
        : scala.Option[List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbSubnetGroups
        : ZIO[Any, AwsError, List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]] =
      AwsError.unwrapOptionField("dbSubnetGroups", dbSubnetGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ) extends zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly {
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val dbSubnetGroups
        : scala.Option[List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]] = scala
      .Option(impl.dbSubnetGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.DBSubnetGroup.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ): zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_2.13-5.17.184.1-sources.jar: zio/aws/rds/model/DescribeDbSubnetGroupsResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeDbSubnetGroupsResponse(
    marker: Optional[String] = Optional.Absent,
    dbSubnetGroups: Optional[Iterable[zio.aws.rds.model.DBSubnetGroup]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse = {
    import DescribeDbSubnetGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbSubnetGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbSubnetGroups)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbSubnetGroupsResponse.wrap(buildAwsValue())
}
object DescribeDbSubnetGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbSubnetGroupsResponse =
      zio.aws.rds.model.DescribeDbSubnetGroupsResponse(
        marker.map(value => value),
        dbSubnetGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def dbSubnetGroups: Optional[List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbSubnetGroups
        : ZIO[Any, AwsError, List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]] =
      AwsError.unwrapOptionField("dbSubnetGroups", dbSubnetGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ) extends zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val dbSubnetGroups
        : Optional[List[zio.aws.rds.model.DBSubnetGroup.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbSubnetGroups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.rds.model.DBSubnetGroup.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbSubnetGroupsResponse
  ): zio.aws.rds.model.DescribeDbSubnetGroupsResponse.ReadOnly = new Wrapper(
    impl
  )
}
